@@ -5,7 +5,7 @@
 # The latest version can be found at http://www.speech.kth.se/wavesurfer/
 #
 
-package provide surfutil 1.6
+package provide surfutil 1.7
 
 if {[lsearch [package names] msgcat] != -1} {
   namespace eval util {
@@ -405,6 +405,18 @@ proc util::mc {message} {
   }
 }
 
+proc util::mcmax {args} {
+ if {[info procs ::msgcat::mc] != ""} {
+  eval ::msgcat::mcmax $args
+ } else {
+  set len 0
+  foreach str $args {
+   set len [max $len [string length $str]]
+  }
+  return $len
+ }
+}
+
 proc util::chooseColor {colorVar {label ""}} {
  upvar $colorVar color
  set res [eval tk_chooseColor -initialcolor $color]
