@@ -5,9 +5,9 @@
 # The latest version can be found at http://www.speech.kth.se/wavesurfer/
 #
 
-package provide wsurf 1.6
+package provide wsurf 1.7
 package require snack 2.2
-package require surfutil 1.5
+package require surfutil 1.7
 
 namespace eval wavebar {
  variable Info
@@ -44,6 +44,7 @@ namespace eval wavebar {
     -maxtime            0.0 \
     -formattimecommand  "" \
     -scrollevent        1 \
+    -pixelspersecond    0.0 \
     -zoomevent          {{Shift 1} 2} \
     ]
   set Info(emptysound) [snack::sound]
@@ -66,6 +67,7 @@ proc wavebar::create {w args} {
  set d(isInteractive) 0
  set d(mintime) 0
  set d(maxtime) 0
+ set d(pixelspersecond) 0
  set d(sound) ""
 
  frame $w
@@ -197,7 +199,8 @@ proc wavebar::_msgTime {w} {
  upvar [namespace current]::${w}::data d
 
  if {[info exists d(messageproc)]} {
-  set msg [format "WaveBar - \[%s %s\]" [eval $d(formattimecommand) $d(time1)] [eval $d(formattimecommand) $d(time2)]]
+  set msg [format "WaveBar - \[%s %s\] %.2fmm/s" [eval $d(formattimecommand) $d(time1)] [eval $d(formattimecommand) $d(time2)] \
+	       [expr $d(pixelspersecond) / [winfo fpixels $w 1m]]]
   $d(messageproc) $msg
  }
 }
@@ -278,6 +281,9 @@ proc wavebar::configure {w args} {
      syncLimits $w
      set needUpdate 1
     }
+    -pixelspersecond {
+     set d(pixelspersecond) $val
+    }
     -shapefile -
     -progress {
      $w.c0 itemconf waveform $opt $val
